==> frodoio-0.9.4.tgz: package/test/unit/index.spec.js <==
var expect = require('chai').expect;
var sinon = require('sinon');
var Etcd = require('node-etcd');
var Frodo = require('../../src/index');
var Q = require('q');

describe('Frodo unit tests', function () {
  var frodo;
  var mock;

  beforeEach(function (done) {
    frodo = new Frodo({ context: 'test', lazy: true });
    mock = sinon.mock(frodo.etcd);
    mock.expects('get').returns(Q([{node: { nodes: [{value: 'first'}, {value: 'second'}] }}]));
    frodo.init().then(done, done);
  });

  afterEach(function () {

  });

  describe('#servers', function () {
    it('Should get all servers', function (done) {
      frodo.servers().then(function (servers) {
        frodo.close();
        mock.verify();
        expect(servers).to.eql(['first', 'second']);
        done();
      }, done).done();
    });
  });

  describe('#addServer', function () {
    it('Should add a server', function (done) {
      mock.expects('set').withArgs('test/hosts/third', 'third').returns(Q());
      frodo.addServer('third').then(function () {
        frodo.close();
        mock.verify();
        done();
      }, done).done();;
    });
  });

  describe('#removeServer', function () {
    it('Should remove a server', function (done) {
      mock.expects('del').withArgs('test/hosts/second').returns(Q());
      frodo.removeServer('second').then(function () {
        frodo.close();
        mock.verify();
        done();
      }, done).done();;
    });
  });

  describe('#serverById', function () {
    it('Should get a server by some id', function (done) {
      frodo.serverById('4f8583b5e5a4e46a64000002').then(function (server) {
        expect(['first', 'second']).to.contain(server);
        frodo.close();
        mock.verify();
        done();
      }, done).done();;
    });
  });
});

==> frodoio-3.1.0.tgz: package/test/unit/index.spec.js <==
var expect = require('chai').expect;
var sinon = require('sinon');
var Etcd = require('node-etcd');
var Frodo = require('../../src/index');
var Q = require('q');

describe('Frodo unit tests', function () {
  var frodo;
  var mock;

  beforeEach(function (done) {
    frodo = new Frodo({ context: 'test', lazy: true });
    mock = sinon.mock(frodo.etcd);
    mock.expects('get').returns(Q([{node: { nodes: [{value: 'first'}, {value: 'second'}] }}]));
    frodo.init().then(done, done);
  });

  afterEach(function () {

  });
  var pid = process.pid;

  describe('#servers', function () {
    it('Should get all servers', function (done) {
      frodo.servers().then(function (servers) {
        frodo.close();
        mock.verify();
        expect(servers).to.eql(['first', 'second']);
        done();
      }, done).done();
    });
  });

  describe('#addServer', function () {
    it('Should add a server', function (done) {
      mock.expects('set').withArgs('test/hosts/third:' + pid, 'third').returns(Q());
      frodo.addServer('third').then(function () {
        frodo.close();
        mock.verify();
        done();
      }, done).done();;
    });
  });

  describe('#removeServer', function () {
    it('Should remove a server', function (done) {
      mock.expects('del').withArgs('test/hosts/second:' + pid).returns(Q());
      frodo.removeServer('second').then(function () {
        frodo.close();
        mock.verify();
        done();
      }, done).done();;
    });
  });

  describe('#serverById', function () {
    it('Should get a server by some id', function (done) {
      frodo.serverById('4f8583b5e5a4e46a64000002').then(function (server) {
        expect(['first', 'second']).to.contain(server);
        frodo.close();
        mock.verify();
        done();
      }, done).done();;
    });
  });
});
